@@ -1,12 +1,9 @@
 (** Public API of [ppx_deriving] executable. *)
 
-open Parsetree
+open Ppxlib
 
-#if OCAML_VERSION >= (4, 05, 0)
 type tyvar = string Location.loc
-#else
-type tyvar = string
-#endif
+
 
 (** {2 Registration} *)
 
@@ -79,35 +76,9 @@ val create :
 val lookup : string -> deriver option
 
 (** {2 Error handling} *)
-val raise_errorf : ?sub:Location.error list ->
+val raise_errorf : ?sub:Ocaml_common.Location.error list ->
                    ?loc:Location.t -> ('a, unit, string, 'b) format4 -> 'a
 
-(** {2 Compatibility module Const} *)
-
-(** [Ast_helper.Const] is not defined in OCaml <4.03. *)
-
-type constant =
-  #if OCAML_VERSION >= (4, 03, 0)
-    Parsetree.constant
-  #else
-    Asttypes.constant
-  #endif
-
-#if OCAML_VERSION >= (4, 03, 0)
-  module Const = Ast_helper.Const
-#else
-  module Const : sig
-    val char : char -> constant
-    val string : ?quotation_delimiter:string -> string -> constant
-    val integer : ?suffix:char -> string -> constant
-    val int : ?suffix:char -> int -> constant
-    val int32 : ?suffix:char -> int32 -> constant
-    val int64 : ?suffix:char -> int64 -> constant
-    val nativeint : ?suffix:char -> nativeint -> constant
-    val float : ?suffix:char -> string -> constant
-  end
-#endif
-
 (** {2 Coercions} *)
 
 (** [string_of_core_type typ] unparses [typ], omitting any attributes. *)
@@ -115,7 +86,7 @@ val string_of_core_type : Parsetree.core_type -> string
 
 (** [string_of_constant_opt c] returns [Some s] if the constant [c]
     is a string [s], [None] otherwise. *)
-val string_of_constant_opt : constant -> string option
+val string_of_constant_opt : Parsetree.constant -> string option
 
 (** [string_of_expression_opt e] returns [Some s] if the expression [e]
     is a string constant [s], [None] otherwise. *)
@@ -133,37 +104,37 @@ module Arg : sig
   (** A type of conversion functions.
 
       A conversion function of type ['a conv] converts a raw expression into an
-      argument of type ['a]. Or returns [Result.Error "error"] if conversion
+      argument of type ['a]. Or returns [Error "error"] if conversion
       fails. *)
-  type 'a conv = expression -> ('a, string) Result.result
+  type 'a conv = expression -> ('a, string) result
 
   (** [expr] returns the input expression as-is. *)
   val expr : expression conv
 
   (** [bool expr] extracts a boolean constant from [expr], or returns
-      [Result.Error "boolean"] if [expr] does not contain a boolean literal. *)
+      [Error "boolean"] if [expr] does not contain a boolean literal. *)
   val bool : bool conv
 
   (** [int expr] extracts an integer constant from [expr], or returns
-      [Result.Error "integer"] if [expr] does not contain an integer literal. *)
+      [Error "integer"] if [expr] does not contain an integer literal. *)
   val int : int conv
 
   (** [string expr] extracts a string constant from [expr], or returns
-      [Result.Error "string"] if [expr] does not contain a string literal. *)
+      [Error "string"] if [expr] does not contain a string literal. *)
   val string : string conv
 
   (** [char expr] extracts a char constant from [expr], or returns
-      [Result.Error "char"] if [expr] does not contain a char literal. *)
+      [Error "char"] if [expr] does not contain a char literal. *)
   val char : char conv
 
   (** [enum values expr] extracts a polymorphic variant constant from [expr],
-      or returns [Result.Error "one of: `a, `b, ..."] if [expr] does not
+      or returns [Error "one of: `a, `b, ..."] if [expr] does not
       contain a polymorphic variant constructor included in [values]. *)
   val enum : string list -> string conv
 
   (** [list f expr] extracts a list constant from [expr] and maps every element
-      through [f], or returns [Result.Error "list:..."] where [...] is the
-      error returned by [f], or returns [Result.Error "list"] if [expr] does
+      through [f], or returns [Error "list:..."] where [...] is the
+      error returned by [f], or returns [Error "list"] if [expr] does
       not contain a list. *)
   val list : 'a conv -> 'a list conv
 
@@ -213,7 +184,7 @@ val create_quoter : unit -> quoter
 val quote : quoter:quoter -> expression -> expression
 
 (** [sanitize module_ quoter expr] wraps [expr] in a way that ensures that the
-    contents of [module_] and {!Pervasives}, as well as the identifiers in
+    contents of [module_] and {!Stdlib}, as well as the identifiers in
     expressions returned by [quote] are in scope, and returns the wrapped
     expression. [module_] defaults to {!Ppx_deriving_runtime} if it's not
     provided*)
@@ -265,7 +236,7 @@ val attr_warning: expression -> attribute
 val free_vars_in_core_type : core_type -> tyvar list
 
 (** [remove_pervasives ~deriver typ] removes the leading "Pervasives."
-    module name in longidents.
+    and "Stdlib." module name in longidents.
     Type expressions marked with [\[\@nobuiltin\]] are ignored.
 
     The name of the deriving plugin should be passed as [deriver]; it is used
@@ -360,9 +331,58 @@ val strong_type_of_type: core_type -> core_type
 
 (** The mapper for the currently loaded deriving plugins. It is useful for
     recursively processing expression-valued attributes. *)
-val mapper : Ast_mapper.mapper
+
+class mapper : Ast_traverse.map
 
 (** {2 Miscellanea} *)
 
 (** [hash_variant x] ≡ [Btype.hash_variant x]. *)
 val hash_variant : string -> int
+
+module Ast_convenience : sig
+  val mkloc : 'a -> Location.t -> 'a loc
+
+  val mknoloc : 'a -> 'a loc
+
+  val unit : unit -> expression
+
+  val punit : unit -> pattern
+
+  val int : int -> expression
+
+  val pint : int -> pattern
+
+  val str : string -> expression
+
+  val evar : string -> expression
+
+  val pvar : string -> pattern
+
+  val app : expression -> expression list -> expression
+
+  val constr : string -> expression list -> expression
+
+  val pconstr : string -> pattern list -> pattern
+
+  val tconstr : string -> core_type list -> core_type
+
+  val record : (string * expression) list -> expression
+
+  val precord : closed:closed_flag -> (string * pattern) list -> pattern
+
+  val tuple : expression list -> expression
+
+  val ptuple : pattern list -> pattern
+
+  val has_attr : string -> attributes -> bool
+
+  val find_attr : string -> attributes -> payload option
+
+  module Label : sig
+    val nolabel : arg_label
+
+    val labelled : string -> arg_label
+
+    val optional : string -> arg_label
+  end
+end
