@@ -21,20 +21,15 @@ type nonrec bytes = bytes
 
 (** {2 Predefined modules}
     {3 Operations on predefined types} *)
+
 #if OCAML_VERSION >= (4, 07, 0)
 include module type of struct
   include Stdlib
 end
 
+module Stdlib = Stdlib
+
 module Result : sig
-  (* Type manifest shoud be [('a, 'b) result]:
-     - it can't be [Result.t] because [Result] is not defined in 4.07 std-lib
-       and the result package just exposes [Result.t] as an alias to [result]
-       without re-exporting the constructors
-     - it can't be [Result.result] because the [include Stdlib] above makes
-       [Result] be [Stdlib.Result] (shadowing the [Result] module from the
-       result package), and [Stdlib.Result] does not define [result] (that's
-       why we override the [Result] module as the first place. *)
   type ('a, 'b) t = ('a, 'b) result =
     | Ok of 'a
     | Error of 'b
@@ -77,24 +72,21 @@ module Format = Format
 module Buffer = Buffer
 
 module Result : sig
-  type ('a, 'b) t = ('a, 'b) Result.result =
+  type ('a, 'b) t = ('a, 'b) result =
     | Ok of 'a
     | Error of 'b
 
-  (* we also expose Result.result for backward-compatibility
-     with the Result package! *)
-  type ('a, 'b) result = ('a, 'b) Result.result =
+  (* we also expose Result.result for backward-compatibility *)
+  type nonrec ('a, 'b) result = ('a, 'b) result =
     | Ok of 'a
     | Error of 'b
 end
-#endif
 
-#if OCAML_VERSION < (4, 08, 0)
 module Option : sig
   type 'a t = 'a option
 
   val get : 'a t -> 'a
 
-  val to_result : none:'e -> 'a option -> ('a, 'e) Result.result
+  val to_result : none:'e -> 'a option -> ('a, 'e) result
 end
 #endif
