@@ -1,14 +1,10 @@
-open Parsetree
 open OUnit2
 
 let string_of_tyvar tyvar =
-#if OCAML_VERSION >= (4, 05, 0)
   tyvar.Location.txt
-#else
-  tyvar
-#endif
 
 let test_free_vars ctxt =
+  let loc = !Ast_helper.default_loc in
   let free_vars = Ppx_deriving.free_vars_in_core_type in
   let (!!) li = List.map string_of_tyvar li in
   let printer li =
