@@ -9,8 +9,9 @@ let test_inline_shorthand ctxt =
   assert_equal ~printer:(fun x -> x)
                "[(1, 1); (2, 0)]" ([%show: (int * int) list] [(1,1); (2,0)])
 
-type optional_deriver = string
-[@@deriving missing { optional = true }]
+(* TODO: optional is incompatible with ppxlib derivers: https://github.com/ocaml-ppx/ppx_deriving/issues/247 *)
+(* type optional_deriver = string
+[@@deriving missing { optional = true }] *)
 
 type prefix = {
   field : int [@deriving.eq.compare fun _ _ -> true]
