@@ -6,7 +6,7 @@ let test_ref_included
 let test_ref_qualified
   (x : 'a ref)
   =
-  (x : 'a Ppx_deriving_runtime.Pervasives.ref[@ocaml.warning "-3"])
+  (x : 'a Ppx_deriving_runtime.Stdlib.ref)
 
 let test_backtrace
   (x : Printexc.raw_backtrace)
@@ -19,21 +19,21 @@ let test_hashtbl
   (x : ('a, 'b) Ppx_deriving_runtime.Hashtbl.t)
 
 let test_result_qualified
-  (x : ('a, 'b) Result.result)
+  (x : ('a, 'b) result)
   =
-  (x : ('a, 'b) Ppx_deriving_runtime.Result.t)
+  (x : ('a, 'b) result)
 
 #if OCAML_VERSION >= (4, 06, 0)
 let test_result_included
   (x : ('a, 'b) result)
   =
-  (x : ('a, 'b) Ppx_deriving_runtime.Result.t)
+  (x : ('a, 'b) result)
 #endif
 
 #if OCAML_VERSION >= (4, 07, 0)
 let test_result_in_stdlib
   (x : ('a, 'b) Stdlib.result)
   =
-  (x : ('a, 'b) Ppx_deriving_runtime.Result.t)
+  (x : ('a, 'b) result)
 #endif
 
